@@ -25,22 +25,9 @@
 
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-window.h>
-#include <epiphany/ephy-extension.h>
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-embed-single.h>
-#include <epiphany/ephy-embed-shell.h>
-#include <epiphany/ephy-statusbar.h>
+#include <epiphany/epiphany.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkrc.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
 
@@ -170,7 +157,7 @@ manage_certificates_cb (GtkAction *action,
 	g_return_if_fail (manager != NULL);
 
 	window = gtk_widget_get_toplevel (manager);
-	g_return_if_fail (GTK_WIDGET_TOPLEVEL (window));
+	g_return_if_fail (gtk_widget_is_toplevel (window));
 
 	gtk_window_set_role (GTK_WINDOW (window), "epiphany-certificate-manager");
 	gtk_window_set_title (GTK_WINDOW (window), _("Certificates"));
@@ -201,7 +188,7 @@ manage_devices_cb (GtkAction *action,
 	g_return_if_fail (manager != NULL);
 
 	window = gtk_widget_get_toplevel (manager);
-	g_return_if_fail (GTK_WIDGET_TOPLEVEL (window));
+	g_return_if_fail (gtk_widget_is_toplevel (window));
 
 	gtk_window_set_role (GTK_WINDOW (window), "epiphany-security-device-manager");
 	gtk_window_set_title (GTK_WINDOW (window), _("Security Devices"));
